package main

import (
	"flag"
	"fmt"

	api "example.com/api"
	authdiscord "example.com/auth/discord"
	database "example.com/database"
)

var defaultConfigPath = "../config.toml"

func parseArgs() map[string]string {
	config := flag.String("config", defaultConfigPath, fmt.Sprintf("path to the config file; Default: \"%s\"", defaultConfigPath))
	flag.Parse()
	return map[string]string{
		"config": *config,
	}
}

func initializeAPIServer(filepath string) {
	api.GlobalConfig.ParseConfig(filepath)
	api.GlobalDatabase = database.InitializeDatabase(api.GlobalConfig.Database.Path)
	api.GlobalOAuth = authdiscord.CreateDiscordOAuthConfig(api.GlobalConfig)
	api.SetFilteredModels()
}

func main() {
	args := parseArgs()
	initializeAPIServer(args["config"])
	router := api.InitializeRouter()
	router.Run(api.GlobalConfig.GetAPIListenHost())
}
