package authdiscord

import (
	"encoding/json"
	"io"

	configserver "example.com/config/server"

	"github.com/gin-gonic/gin"
	"github.com/ravener/discord-oauth2"
	"golang.org/x/oauth2"
)

type DiscordUser struct {
	Id                     string  `json:"id"`
	Username               string  `json:"username"`
	Avatar                 string  `json:"avatar"`
	Discriminator          string  `json:"discriminator"`
	Public_Flags           float64 `json:"public_flags"`
	Flags                  float64 `json:"flags"`
	Banner                 string  `json:"banner"`
	Accent_Color           float64 `json:"accent_color"`
	Global_Name            string  `json:"global_name"`
	Avatar_Decoration_Data struct {
		Asset      string `json:"asset"`
		Sku_Id     string `json:"sku_id"`
		Expires_At string `json:"expired_at"`
	} `json:"avatar_decoration_data"`
	Collectibles  string  `json:"collectibles"`
	Banner_Color  string  `json:"banner_color"`
	Clan          string  `json:"clan"`
	Primary_Guild string  `json:"primary_guild"`
	Mfa_Enabled   bool    `json:"mfa_enabled"`
	Locale        string  `json:"locale"`
	Premium_Type  float64 `json:"premium_type"`
}

func (discordUser *DiscordUser) Get(context *gin.Context, oauthToken *oauth2.Token, oauthConfig *oauth2.Config) string {
	response, err := oauthConfig.Client(context, oauthToken).Get("https://discord.com/api/users/@me")
	if err != nil || response.StatusCode != 200 {
		if err != nil {
			return err.Error()
		} else {
			return response.Status
		}
	}
	defer response.Body.Close()
	body, err := io.ReadAll(response.Body)
	if err != nil {
		return err.Error()
	}
	json.Unmarshal(body, &discordUser)
	return ""
}

func CreateDiscordOAuthConfig(config configserver.AppConfig) *oauth2.Config {
	oauthconfig := &oauth2.Config{
		ClientID:     config.OAuth.ClientID,
		ClientSecret: config.OAuth.ClientSecret,
		RedirectURL:  config.GetAPIRootDomain() + "/auth/callback",
		Scopes:       []string{discord.ScopeIdentify},
		Endpoint:     discord.Endpoint,
	}
	return oauthconfig
}
