package configserver

import (
	"io"
	"log"
	"os"

	"github.com/pelletier/go-toml/v2"
)

type AppConfig struct {
	API struct {
		Domain string `toml:"domain"`
		Port   string `toml:"port"`
		Https  bool   `toml:"https"`
		Listen string `toml:"listen"`
	} `toml:"api"`
	Frontend struct {
		Domain string `toml:"domain"`
		Port   string `toml:"port"`
		Https  bool   `toml:"https"`
	} `toml:"frontend"`
	OAuth struct {
		ClientID     string `toml:"client_id"`
		ClientSecret string `toml:"client_secret"`
	} `toml:"oauth"`
	Database struct {
		Path string `toml:"path"`
	} `toml:"database"`
}

func (config AppConfig) GetAPIRootDomain() string {
	protocol := "http://"
	if config.API.Https {
		protocol = "https://"
	}
	return protocol + config.API.Domain + ":" + config.API.Port
}

func (config AppConfig) GetFrontendRootDomain() string {
	protocol := "http://"
	if config.Frontend.Https {
		protocol = "https://"
	}
	return protocol + config.Frontend.Domain + ":" + config.Frontend.Port
}

func (config AppConfig) GetAPIListenHost() string {
	return config.API.Listen + ":" + config.API.Port
}

func (config *AppConfig) ParseConfig(configPath string) {
	configFile, err := os.Open(configPath)
	if err != nil {
		log.Fatal(err)
	}
	configFileContent, err := io.ReadAll(configFile)
	if err != nil {
		log.Fatal(err)
	}
	err = toml.Unmarshal(configFileContent, &config)
	if err != nil {
		log.Fatal(err)
	}
}
