package database

import (
	"fmt"
	"log"
	"os"
	"path"

	character "example.com/database/character"
	customization "example.com/database/customization"
	function "example.com/database/function"
	functionset "example.com/database/functionset"
	functiontag "example.com/database/functiontag"
	group "example.com/database/group"
	inventoryslot "example.com/database/inventoryslot"
	item "example.com/database/item"
	itemtag "example.com/database/itemtag"
	person "example.com/database/person"
	role "example.com/database/role"
	schematic "example.com/database/schematic"
	tier "example.com/database/tier"
	user "example.com/database/user"

	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
)

// default: "../db/main.db"
func InitializeDatabase(filepath string) *gorm.DB {
	logfile, err := os.Create(fmt.Sprintf("%s/db.log", path.Dir(filepath)))
	if err != nil {
		log.Fatal("Failed to create database logfile.")
	}
	logger := logger.New(log.New(logfile, "\r\n", log.LstdFlags),
		logger.Config{},
	)
	db, err := gorm.Open(sqlite.Open(filepath), &gorm.Config{
		Logger: logger,
	})
	if err != nil {
		log.Fatal("Failed to connect to database.")
	}
	db.AutoMigrate(
		&user.User{},
		&group.Group{},
		&functiontag.FunctionTag{},
		&itemtag.ItemTag{},
		&function.Function{},
		&functionset.FunctionSet{},
		&tier.Tier{},
		&role.Role{},
		&person.Person{},
		&item.Item{},
		&inventoryslot.InventorySlot{},
		&character.Character{},
		&customization.Customization{},
		&schematic.Schematic{},
	)
	return db
}
